#
# spec file for package agama-products
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           agama-products
#               This will be set by osc services, that will run after this.
Version:        11+793
Release:        11.1
Summary:        Definition of products for the Agama installer
License:        GPL-2.0-only
URL:            https://github.com/opensuse/agama
BuildArch:      noarch
Source0:        agama.tar

%description
Products definition for Agama installer.

%prep
%autosetup -a0 -n agama

%build

%install
install -D -d -m 0755 %{buildroot}%{_datadir}/agama/products.d
install -m 0644 *.yaml %{buildroot}%{_datadir}/agama/products.d

%package opensuse
Summary:        Definition of openSUSE products for the Agama installer.

%description opensuse
Definition of openSUSE products (Tumbleweed, Leap, MicroOS and Slowroll) for the Agama installer.

%files opensuse
%doc README.md
%license LICENSE
%dir %{_datadir}/agama
%dir %{_datadir}/agama/products.d
%{_datadir}/agama/products.d/microos.yaml
%{_datadir}/agama/products.d/tumbleweed.yaml
%{_datadir}/agama/products.d/leap_160.yaml
%{_datadir}/agama/products.d/slowroll.yaml

%package sle
Summary:        Definition of SLE products for the Agama installer.

%description sle
SLE-based products definition for Agama installer.
Definition of SLE-based products (e.g., SUSE Linux Enterprise Server) for the Agama installer.

%files sle
%doc README.md
%license LICENSE
%dir %{_datadir}/agama
%dir %{_datadir}/agama/products.d
%{_datadir}/agama/products.d/sles_160.yaml
%{_datadir}/agama/products.d/sles_sap_160.yaml

%changelog
* Thu Feb 20 2025 Josef Reidinger <jreidinger@suse.com>
- drop sles_sap for aarch64 (bsc#1236370#c8)
* Thu Feb 20 2025 Ancor Gonzalez Sosa <ancor@suse.com>
- Adjust product name of sles_sap_160 and some sizes for the
  storage proposal of several products (gh#openSUSE/agama#2004).
* Wed Feb 19 2025 Josef Reidinger <jreidinger@suse.com>
- Add sudo-policy-wheel-auth-self package as mandatory for products
  that do not do it automatic to allow just non-root user for
  initial login (jsc#PM-2128)
* Thu Feb 13 2025 Lubos Kocman <lubos.kocman@suse.com>
- Change the default lsm to SELinux in enforcing for both Leap and Tumblweed
  keep AppArmor around as an option jsc#PED-12021
  https://news.opensuse.org/2025/02/13/tw-plans-to-adopt-selinux-as-default/
* Fri Jan 24 2025 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Change the registration property in a product's definition to a
  boolean (gh#agama-project/agama#1938).
* Thu Jan 23 2025 Josef Reidinger <jreidinger@suse.com>
- Set installation labels for SLES and SLES4SAP
  (gh#agama-project/agama#1937)
* Mon Jan 20 2025 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Set the license for SLES and SLES4SAP (jsc#PED-11987).
* Mon Jan 20 2025 Angela Briel <abriel@suse.com>
- Add pattern sles_minimal_sap to the user selectable patterns list
  of the SLES product to give the admin the chance to get a minimal
  preparation of the operating system to run SAP workloads on plain
  SLES.
* Thu Jan 16 2025 Josef Reidinger <jreidinger@suse.com>
- Update also base product from SLES-SAP to SLES_SAP(bsc#1235956)
* Mon Jan 13 2025 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Update SLES4SAP ID to SLES_SAP (gh#agama-project/agama#1890).
* Fri Jan 10 2025 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Add the user selectable patterns list to the SLES product
  (gh#agama-project/agama#1885).
* Fri Jan 10 2025 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Update SLES name (gh#agama-project/agama#1883).
* Wed Jan  8 2025 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Add support for products registration (jsc#PED-11192,
  gh#agama-project/agama#1809).
* Tue Jan  7 2025 Lubos Kocman <lubos.kocman@suse.com>
- Drop yast from Leap 16.0 software selection
  code-o-o#leap/features#173
* Mon Jan  6 2025 Angela Briel <abriel@suse.com>
- SLES for SAP Application product:
  Change product description.
  (bsc#1235023)
* Thu Dec  5 2024 Angela Briel <abriel@suse.com>
- SLES for SAP Application product:
  Change the base_product to SLES-SAP.
  Add SAP specific patterns for the default installation and for
  the additional software selection.
  (jsc#PED-11068, jsc#PED-11696)
* Tue Dec  3 2024 Ancor Gonzalez Sosa <ancor@suse.com>
- Temporarily disable adjusting swap to RAM size for all products
  (mitigation for gh#agama-project/agama/#1159).
* Tue Nov 12 2024 Gustavo Yokoyama Ribeiro <gyribeiro@suse.com>
- Add SLES for SAP Application product for SLE based products
  (gh#agama-project/agama/#1764)
* Fri Nov  8 2024 Lubos Kocman <lubos.kocman@suse.com>
- Shorten Leap 16.0 installation_labels
  Neither yast2 partitioner, nor gnome disks
  allowed me to use openSUSE-Leap-DVD-x86_64 as
  the label limit seems to be 16 characters
* Fri Nov  8 2024 Lubos Kocman <lubos.kocman@suse.com>
- Add installation_labels for Leap 16.0
  Let's keep TW style format for now
  (gh#agama-project/agama/#1740)
* Thu Nov  7 2024 Gustavo Yokoyama Ribeiro <gyribeiro@suse.com>
- Fix mandatory patterns for SLES16.0:
  - fix traditional pattern name, patterns-base-traditional package
    provides base_traditional
  - remove base pattern because base_traditional pattern requires it
  (gh#agama-project/agama#1736)
* Wed Nov  6 2024 Gustavo Yokoyama Ribeiro <gyribeiro@suse.com>
- add traditional pattern to mandatory_patterns for SLES16.0 product,
  it will fix missing zypper in initial installation
  (gh#agama-project/agama#1731)
* Wed Oct 30 2024 Gustavo Yokoyama Ribeiro <gyribeiro@suse.com>
- sles_enhanced_base pattern was removed from SLES16, so replace
  it with base pattern (bsc#1232618)
* Tue Oct 22 2024 Ladislav Slezák <lslezak@suse.com>
- Use HTTP repositories for SLES16, HTTPS does not work because
  of the internal SUSE CA used for the server SSL certificate
  (gh#agama-project/agama#1688)
* Thu Oct 17 2024 WesfunOfficial <93811710+WesfunOfficial@users.noreply.github.com>
- Added Slowroll to the product list (gh#agama-project/agama#1674)
* Thu Oct 17 2024 Ladislav Slezák <lslezak@suse.com>
- Fixed typo in the SLES product name (bsc#1231663)
* Tue Sep 24 2024 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Update products translations (gh#openSUSE/agama#1607).
* Thu Sep  5 2024 Lubos Kocman <lubos.kocman@suse.com>
- Show product logo in product selector (gh#openSUSE/agama#1415).
* Tue Sep  3 2024 Lubos Kocman <lubos.kocman@suse.com>
- Add kde to Leap 16.0, remove Xfce until it's fully submitted to 16.0
  initial set of ~800 KDE related packages were just merged to Leap 16.0
* Fri Aug  2 2024 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Adjust Linux Security Modules (LSM) configuration for SLES 16
  (gh#openSUSE/agama#1525):
  - Enable SELinux by default.
  - Drop AppArmor as it is not available.
* Fri Aug  2 2024 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Adjust the SLES 16 repositories (gh#openSUSE/agama#1524):
  - The TEST repositories are more stable at this time.
  - Add s390x and ppc64le repositories.
* Wed Jul 17 2024 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Add a definition for SUSE Linux Enteprise Server
  (gh#openSUSE/agama#1473).
- Generate separate packages for openSUSE and SLE-based products.
* Fri Jul 12 2024 Natasha Ament <stacheldrahtje@gmail.com>
- change url for leap_160.yaml due to typo
* Fri Jul 12 2024 Natasha Ament <stacheldrahtje@gmail.com>
- change url for leap_160.yaml to distribution
* Tue Jul  2 2024 Lubos Kocman <lubos.kocman@suse.com>
- Use specific flavor of openSUSE-repos for each distro
  (gh#openSUSE/agama#1424).
* Tue Jul  2 2024 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Enable Leap 16.0 Alpha (gh#openSUSE/agama#1423).
* Wed Jun 26 2024 Imobach Gonzalez Sosa <igonzalezsosa@suse.com>
- Temporarily remove Leap 16.0 Alpha from the list of products
  (gh#openSUSE/agama#1390).
* Wed Jun 26 2024 Ladislav Slezák <lslezak@suse.com>
- Remove the "32bit" pattern from openSUSE MicroOS
  (gh#openSUSE/agama#1381)
* Mon Jun 24 2024 Lubos Kocman <lubos.kocman@suse.com>
- Add Leap 16 (gh#openSUSE/agama#1371)
* Tue May 21 2024 Richard Brown <rbrown@suse.com>
- Remove definitions for MicroOS Desktop (gh#openSUSE/agama#1243).
* Mon Dec  4 2023 Ancor Gonzalez Sosa <ancor@suse.com>
- Preliminary definitions of openSUSE MicroOS products
- Remove Leap 16.0 for now
* Mon Oct 30 2023 Josef Reidinger <jreidinger@suse.com>
- Initial split of products (gh#openSUSE/agama#602,
  gh#openSUSE/agama#822)
